Praxis de Poitiers Poitiers, France May 28th 2006 17 players François Morand "Tupdog power bleed" Crypt (25 cards, min=4, max=24, avg=2.36) ----------------------------------------- 16x Tupdog 1 POT VIS Gargoyle:3 2x Reverend Blackwood 6 DOM THA obf bishop Tremere antitribu:2 2x Selena 6 AUS DOM THA Tremere antitribu:3 2x Kurt Strauss 5 DOM aus tha Tremere antitribu:2 1x Brooke 3 dom tha Tremere antitribu:2 1x Ember Wright 3 aus dom Tremere antitribu:3 1x Saiz 3 aus dom Tremere antitribu:3 Library (76 cards) Master (14) 3x Blood Doll 2x Dreams of the Sphinx 4x Effective Management 1x Erciyes Fragments, The 1x Fame 1x Information Highway 2x Powerbase: Montreal Action (14) 1x Aranthebes, The Immortal 2x Dominate Kine 6x Govern the Unaligned 4x Graverobbing 1x Rastacourere Ally (1) 1x Carlton Van Wyk Action Modifier (4) 4x Conditioning Reaction (2) 2x Delaying Tactics Combat (41) 9x Earthshock 1x Flow Within the Mountain 12x Immortal Grapple 12x Raking Talons 7x Torn Signpost